@@ -51,6 +51,17 @@ sub category {
   }
 }
 
+sub no_generate {
+  my $self = shift;
+  if (@_) {
+    $self->{no_generate} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{no_generate};
+  }
+}
+
 # Class methods
 sub new {
   my $class = shift;
@@ -65,18 +76,7 @@ sub new {
     confess("The \"config\" field must be defined.");
   }
   
-  my $after_create_compile_info_cbs = $config->after_create_compile_info_cbs;
-  for my $after_create_compile_info_cb (@$after_create_compile_info_cbs) {
-    $after_create_compile_info_cb->($config, $self);
-  }
-  
-  my $config_exe = $config->config_exe;
-  if ($config_exe) {
-    my $global_after_create_compile_info_cbs = $config_exe->global_after_create_compile_info_cbs;
-    for my $global_after_create_compile_info_cb (@$global_after_create_compile_info_cbs) {
-      $global_after_create_compile_info_cb->($config, $self);
-    }
-  }
+  $self->config($config->clone);
   
   return $self;
 }
@@ -103,6 +103,10 @@ sub create_ccflags {
   
   my $config = $self->config;
   
+  my $class_name = $config->class_name;
+  
+  my $config_category = $config->category;
+  
   my @compile_command_args;
   
   my $std = $config->std;
@@ -110,10 +114,7 @@ sub create_ccflags {
     push @compile_command_args, "-std=$std";
   }
   
-  my $optimize = $config->optimize;
-  if (length $optimize) {
-    push @compile_command_args, split(/ +/, $optimize);
-  }
+  push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config->defines};
   
   push @compile_command_args, grep { length $_ } @{$config->ccflags};
   
@@ -127,10 +128,95 @@ sub create_ccflags {
     push @compile_command_args, grep { length $_ } @{$config->dynamic_lib_ccflags};
   }
   
+  my $optimize = $config->optimize;
+  
+  my $config_exe = $config->config_exe;
+  if ($config_exe) {
+    push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config_exe->defines_global};
+    
+    if ($config_category eq 'spvm') {
+      push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config_exe->defines_spvm};
+    }
+    elsif ($config_category eq 'native') {
+      push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config_exe->defines_native};
+      
+      if (defined $class_name) {
+        push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config_exe->defines_native_class($class_name) || []};
+      }
+    }
+    elsif ($config_category eq 'precompile') {
+      push @compile_command_args, map { "-D$_" } grep { length $_ } @{$config_exe->defines_precompile};
+    }
+    
+    push @compile_command_args, grep { length $_ } @{$config_exe->ccflags_global};
+    
+    if ($config_category eq 'spvm') {
+      push @compile_command_args, grep { length $_ } @{$config_exe->ccflags_spvm};
+    }
+    elsif ($config_category eq 'native') {
+      push @compile_command_args, grep { length $_ } @{$config_exe->ccflags_native};
+      
+      if (defined $class_name) {
+        push @compile_command_args, grep { length $_ } @{$config_exe->ccflags_native_class($class_name) || []};
+      }
+    }
+    elsif ($config_category eq 'precompile') {
+      push @compile_command_args, grep { length $_ } @{$config_exe->ccflags_precompile};
+    }
+    
+    if (length $config_exe->optimize_global) {
+      $optimize = $config_exe->optimize_global;
+    }
+    
+    if ($config_category eq 'spvm') {
+      if (length $config_exe->optimize_spvm) {
+        $optimize = $config_exe->optimize_spvm;
+      }
+    }
+    elsif ($config_category eq 'native') {
+      if (length $config_exe->optimize_native) {
+        $optimize = $config_exe->optimize_native;
+      }
+      
+      if (defined $class_name) {
+        if (length $config_exe->optimize_native_class($class_name)) {
+          $optimize = $config_exe->optimize_native_class($config->class_name);
+        }
+      }
+    }
+    elsif ($config_category eq 'precompile') {
+      if (length $config_exe->optimize_precompile) {
+        $optimize = $config_exe->optimize_precompile;
+      }
+    }
+  }
+  
+  if (length $optimize) {
+    push @compile_command_args, split(/ +/, $optimize);
+  }
+  
   # include directories
   {
     my @all_include_dirs;
     
+    if ($config_exe) {
+      push @all_include_dirs, grep { length $_ } @{$config_exe->include_dirs_global};
+      
+      if ($config_category eq 'spvm') {
+        push @all_include_dirs, grep { length $_ } @{$config_exe->include_dirs_spvm};
+      }
+      elsif ($config_category eq 'native') {
+        push @all_include_dirs, grep { length $_ } @{$config_exe->include_dirs_native};
+        
+        if (defined $class_name) {
+          push @all_include_dirs, grep { length $_ } @{$config_exe->include_dirs_native_class($class_name) || []};
+        }
+      }
+      elsif ($config_category eq 'precompile') {
+        push @all_include_dirs, grep { length $_ } @{$config_exe->include_dirs_precompile};
+      }
+    }
+    
     # SPVM core native directory
     my $spvm_core_include_dir = $config->spvm_core_include_dir;
     if (length $spvm_core_include_dir) {
@@ -215,7 +301,14 @@ Gets and sets the C<output_file> field, an output file.
 
 Gets and sets the C<category> field.
 
-These are C<precompile_class>, C<native_class>, C<native_source>, C<spvm_core>, C<bootstrap>.
+These are C<native_class>, C<native_source>, C<precompile_class>, C<spvm>, C<spvm_core>.
+
+=head2 no_generate
+
+  my $no_generate = $link_info->no_generate;
+  $link_info->no_generate($no_generate);
+
+Gets and sets the C<no_generate> field. If this field is a true value, the output file is not generated.
 
 =head1 Class Methods
 
@@ -237,6 +330,10 @@ undef
 
 undef
 
+=item * L</"no_generate">
+
+undef
+
 =back
 
 Exceptions:
